pub struct PHASEGroupPreset { /* private fields */ }PHASEGroupPreset only.Expand description
A PHASEGroupPreset holds a collection of PHASEGroupPresetSetting objects and other parameters to be applied all at once during playback.
Initialize beforehand, and use activate or deactivate to switch to the new preset during playback. Activating a preset will automatically deactivate the current one.
See also Apple’s documentation
Implementations
Sourceimpl PHASEGroupPreset
impl PHASEGroupPreset
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new() -> Retained<Self>
Sourcepub unsafe fn initWithEngine_settings_timeToTarget_timeToReset(
this: Allocated<Self>,
engine: &PHASEEngine,
settings: &NSDictionary<NSString, PHASEGroupPresetSetting>,
time_to_target: c_double,
time_to_reset: c_double,
) -> Retained<Self>
Available on crate feature PHASEEngine only.
pub unsafe fn initWithEngine_settings_timeToTarget_timeToReset( this: Allocated<Self>, engine: &PHASEEngine, settings: &NSDictionary<NSString, PHASEGroupPresetSetting>, time_to_target: c_double, time_to_reset: c_double, ) -> Retained<Self>
PHASEEngine only.Create a new PHASEGroupPreset object with a given PHASEEngine object.
Parameter engine: The PHASEEngine object to register this preset with.
Parameter settings: A dictionary containing PHASEGroupPresetSetting objects paired with PHASEGroup objects as keys.
Parameter timeToTarget: The time interval that all group settings in this preset will take to gradually fade to the new value
Parameter timeToReset: The time interval that all group settings in this preset will take to gradually fade to the unity value
Note: The timeToTarget and timeToReset are scaled by unitsPerSecond internally, so can be provided at the client’s native time scale.
Sourcepub unsafe fn settings(
&self,
) -> Retained<NSDictionary<NSString, PHASEGroupPresetSetting>>
pub unsafe fn settings( &self, ) -> Retained<NSDictionary<NSString, PHASEGroupPresetSetting>>
The collection of PHASEGroupPresetSetting objects to apply when this preset is activated.
Sourcepub unsafe fn timeToTarget(&self) -> c_double
pub unsafe fn timeToTarget(&self) -> c_double
The time interval that all group settings in this preset will take to gradually fade to the new value
Note: The timeToTarget is scaled by unitsPerSecond internally, so can be provided at the client’s native time scale.
Sourcepub unsafe fn timeToReset(&self) -> c_double
pub unsafe fn timeToReset(&self) -> c_double
The time interval that all group settings in this preset will take to gradually fade to the unity value
Note: The timeToReset is scaled by unitsPerSecond internally, so can be provided at the client’s native time scale.
Sourcepub unsafe fn activate(&self)
pub unsafe fn activate(&self)
Activate this preset in the PHASEEngine object it was initialized with. The internal timeToTarget value is used. The current preset will be deactivated automatically.
Sourcepub unsafe fn activateWithTimeToTargetOverride(
&self,
time_to_target_override: c_double,
)
pub unsafe fn activateWithTimeToTargetOverride( &self, time_to_target_override: c_double, )
Activate this preset in the PHASEEngine object it was initialized with. The current preset will be deactivated automatically.
Parameter timeToTargetOverride: Override the timeToTarget value in the preset with this value.
Note: The timeToTargetOverride is scaled by unitsPerSecond internally, so can be provided at the client’s native time scale.
Sourcepub unsafe fn deactivate(&self)
pub unsafe fn deactivate(&self)
Deactivate this preset and return the system to default unity values. The internal timeToReset value is used.
Sourcepub unsafe fn deactivateWithTimeToResetOverride(
&self,
time_to_reset_override: c_double,
)
pub unsafe fn deactivateWithTimeToResetOverride( &self, time_to_reset_override: c_double, )
Deactivate this preset and return the system to default unity values.
Parameter timeToResetOverride: Override the timeToReset value in the preset with this value.
Note: The timeToResetOverride is scaled by unitsPerSecond internally, so can be provided at the client’s native time scale.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for PHASEGroupPreset
impl AsRef<AnyObject> for PHASEGroupPreset
Sourceimpl AsRef<NSObject> for PHASEGroupPreset
impl AsRef<NSObject> for PHASEGroupPreset
Sourceimpl AsRef<PHASEGroupPreset> for PHASEGroupPreset
impl AsRef<PHASEGroupPreset> for PHASEGroupPreset
Sourceimpl Borrow<AnyObject> for PHASEGroupPreset
impl Borrow<AnyObject> for PHASEGroupPreset
Sourceimpl Borrow<NSObject> for PHASEGroupPreset
impl Borrow<NSObject> for PHASEGroupPreset
Sourceimpl ClassType for PHASEGroupPreset
impl ClassType for PHASEGroupPreset
Sourceconst NAME: &'static str = "PHASEGroupPreset"
const NAME: &'static str = "PHASEGroupPreset"
Sourcetype ThreadKind = <<PHASEGroupPreset as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<PHASEGroupPreset as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for PHASEGroupPreset
impl Debug for PHASEGroupPreset
Sourceimpl Deref for PHASEGroupPreset
impl Deref for PHASEGroupPreset
Sourceimpl Hash for PHASEGroupPreset
impl Hash for PHASEGroupPreset
Sourceimpl Message for PHASEGroupPreset
impl Message for PHASEGroupPreset
Sourceimpl NSObjectProtocol for PHASEGroupPreset
impl NSObjectProtocol for PHASEGroupPreset
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref