pub struct PHASEGroupPresetSetting { /* private fields */ }PHASEGroupPreset only.Expand description
A PHASEGroupPresetSetting is an object that holds settings that can be applied to a PHASEGroup object.
These can be either be manually created and added to a PHASEGroupPreset object, or created inline using PHASEGroupPreset addGroup.
See also Apple’s documentation
Implementations
Sourceimpl PHASEGroupPresetSetting
impl PHASEGroupPresetSetting
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new() -> Retained<Self>
Sourcepub unsafe fn initWithGain_rate_gainCurveType_rateCurveType(
this: Allocated<Self>,
gain: c_double,
rate: c_double,
gain_curve_type: PHASECurveType,
rate_curve_type: PHASECurveType,
) -> Retained<Self>
Available on crate feature PHASETypes only.
pub unsafe fn initWithGain_rate_gainCurveType_rateCurveType( this: Allocated<Self>, gain: c_double, rate: c_double, gain_curve_type: PHASECurveType, rate_curve_type: PHASECurveType, ) -> Retained<Self>
PHASETypes only.Initialize the PHASEGroupPresetSetting object with an existing PHASEGroup object.
Parameter gain: The main gain setting to apply to the group. Values are clamped to the range [0, 1]. Default value is 1.
Parameter rate: The playback rate setting to apply to the group. Values are clamped to the range [0.25, 4]. Default value is 1.
Parameter gainCurveType: The type of curve to apply to the gain as the preset changes to this new setting.
Parameter rateCurveType: The type of curve to apply to the rate as the preset changes to this new setting.
Sourcepub unsafe fn gain(&self) -> c_double
pub unsafe fn gain(&self) -> c_double
Linear gain scalar.
Note: Values are clamped to the range [0, 1]. Default value is 1.
Sourcepub unsafe fn gainCurveType(&self) -> PHASECurveType
Available on crate feature PHASETypes only.
pub unsafe fn gainCurveType(&self) -> PHASECurveType
PHASETypes only.The type of curve to apply to the gain as the preset changes to this new setting.
Sourcepub unsafe fn rateCurveType(&self) -> PHASECurveType
Available on crate feature PHASETypes only.
pub unsafe fn rateCurveType(&self) -> PHASECurveType
PHASETypes only.The type of curve to apply to the rate as the preset changes to this new setting.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for PHASEGroupPresetSetting
impl AsRef<AnyObject> for PHASEGroupPresetSetting
Sourceimpl AsRef<NSObject> for PHASEGroupPresetSetting
impl AsRef<NSObject> for PHASEGroupPresetSetting
Sourceimpl Borrow<AnyObject> for PHASEGroupPresetSetting
impl Borrow<AnyObject> for PHASEGroupPresetSetting
Sourceimpl Borrow<NSObject> for PHASEGroupPresetSetting
impl Borrow<NSObject> for PHASEGroupPresetSetting
Sourceimpl ClassType for PHASEGroupPresetSetting
impl ClassType for PHASEGroupPresetSetting
Sourceconst NAME: &'static str = "PHASEGroupPresetSetting"
const NAME: &'static str = "PHASEGroupPresetSetting"
Sourcetype ThreadKind = <<PHASEGroupPresetSetting as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<PHASEGroupPresetSetting as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for PHASEGroupPresetSetting
impl Debug for PHASEGroupPresetSetting
Sourceimpl Deref for PHASEGroupPresetSetting
impl Deref for PHASEGroupPresetSetting
Sourceimpl Hash for PHASEGroupPresetSetting
impl Hash for PHASEGroupPresetSetting
Sourceimpl Message for PHASEGroupPresetSetting
impl Message for PHASEGroupPresetSetting
Sourceimpl NSObjectProtocol for PHASEGroupPresetSetting
impl NSObjectProtocol for PHASEGroupPresetSetting
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref